@@ -63,8 +63,16 @@ out:
 
 }
 
+static void fini_selinuxmnt(void) __attribute__ ((destructor));
+
+static void fini_selinuxmnt(void)
+{
+	free(selinux_mnt);
+	selinux_mnt = NULL;
+}
+
 void set_selinuxmnt(char *mnt)
 {
-	selinux_mnt = mnt;
+	selinux_mnt = strdup(mnt);
 }
  
