@@ -16,7 +16,7 @@ int matchmediacon(const char *media,
 {
 	const char *path = selinux_media_context_path();
 	FILE *infile;
-	char *ptr, *ptr2;
+	char *ptr, *ptr2=NULL;
 	int found=-1;
 	char current_line[PATH_MAX];
 	if ((infile = fopen(path, "r")) == NULL)
