@@ -29,7 +29,10 @@ static void (*myprintf)(const char *fmt, ...) = &default_printf;
 
 void set_matchpathcon_printf(void (*f)(const char *fmt, ...))
 {
-	myprintf = f;
+	if (f)
+		myprintf = f;
+	else
+		myprintf = &default_printf;
 }
 
 static int default_invalidcon(const char *path, unsigned lineno, char *context)
@@ -45,7 +48,17 @@ static int (*myinvalidcon)(const char *p, unsigned l, char *c) = &default_invali
 
 void set_matchpathcon_invalidcon(int (*f)(const char *p, unsigned l, char *c))
 {
-	myinvalidcon = f;
+	if (f)
+		myinvalidcon = f;
+	else
+		myinvalidcon = &default_invalidcon;
+}
+
+static unsigned int myflags;
+
+void set_matchpathcon_flags(unsigned int flags)
+{
+	myflags = flags;
 }
 
 /*
@@ -311,6 +324,9 @@ void matchpathcon_filespec_destroy(void)
 	file_spec_t *fl, *tmp;
 	int h;
 
+	if (!fl_head)
+		return;
+
 	for (h = 0; h < HASH_BUCKETS; h++) {
 		fl = fl_head[h].next;
 		while (fl) {
@@ -517,14 +533,14 @@ static int process_line( const char *path, char *line_buf, int pass, unsigned li
 int matchpathcon_init(const char *path)
 {
 	FILE *fp;
-	FILE *localfp;
-	FILE *homedirfp;
+	FILE *localfp = NULL;
+	FILE *homedirfp = NULL;
 	char local_path[PATH_MAX + 1];
 	char homedir_path[PATH_MAX + 1];
 	char *line_buf = NULL;
 	size_t line_len = 0;
 	unsigned int lineno, pass, i, j, maxnspec;
-	spec_t *spec_copy;
+	spec_t *spec_copy=NULL;
 	int status=-1;
 
 	/* Open the specification file. */
@@ -534,15 +550,17 @@ int matchpathcon_init(const char *path)
 		return -1;
 	__fsetlocking(fp, FSETLOCKING_BYCALLER);
 
-	snprintf(homedir_path, sizeof(homedir_path), "%s.homedirs", path);
-	homedirfp = fopen(homedir_path, "r");
-	if (homedirfp != NULL)
-		__fsetlocking(homedirfp, FSETLOCKING_BYCALLER);
+	if ((myflags & MATCHPATHCON_BASEONLY) == 0) {
+		snprintf(homedir_path, sizeof(homedir_path), "%s.homedirs", path);
+		homedirfp = fopen(homedir_path, "r");
+		if (homedirfp != NULL)
+			__fsetlocking(homedirfp, FSETLOCKING_BYCALLER);
 
-	snprintf(local_path, sizeof(local_path), "%s.local", path);
-	localfp = fopen(local_path, "r");
-	if (localfp != NULL)
-		__fsetlocking(localfp, FSETLOCKING_BYCALLER);
+		snprintf(local_path, sizeof(local_path), "%s.local", path);
+		localfp = fopen(local_path, "r");
+		if (localfp != NULL)
+			__fsetlocking(localfp, FSETLOCKING_BYCALLER);
+	}
 
 	/* 
 	 * Perform two passes over the specification file.
