@@ -36,7 +36,7 @@ int rpm_execcon(unsigned int verified __attribute__((unused)),
 		if (context_type_set(con, "rpm_script_t"))
 			goto out;
 		freecon(newcon);
-		newcon = context_str(con);
+		newcon = strdup(context_str(con));
 		if (!newcon)
 			goto out;
 	}
