@@ -166,6 +166,22 @@ static void init_selinux_policyroot(void)
   use_compat_file_path = 0;
 }
 
+static void fini_selinux_policyroot(void) __attribute__ ((destructor));
+
+static void fini_selinux_policyroot(void)
+{
+  int i;
+  if (use_compat_file_path) {
+	  selinux_policyroot = NULL;
+	  return;
+  }
+  free(selinux_policyroot);
+  selinux_policyroot = NULL;
+  for (i = 0; i < NEL; i++) {
+	  free(file_paths[i]);
+	  file_paths[i] = NULL;
+  }  
+}
 
 static const char *get_path(int idx)
 {
